@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2017-2020
+# Copyright Louis Paternault 2016-2021
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -167,9 +167,9 @@ import types
 
 import pkg_resources
 
-VERSION = "1.1.2"
-__AUTHOR__ = "Louis Paternault (spalax+python@gresille.org)"
-__COPYRIGHT__ = "(C) 2017-2020 Louis Paternault. GNU GPL 3 or later."
+VERSION = "1.2.0"
+__AUTHOR__ = "Louis Paternault (spalax@gresille.org)"
+__COPYRIGHT__ = "(C) 2017-2021 Louis Paternault. GNU GPL 3 or later."
 __all__ = argparse.__all__ + ["ERROR", "IGNORE", "DOUBLE", "RAISE"]
 
 ################################################################################
@@ -308,7 +308,7 @@ class _SubCommandsDispatch(
             if ondouble == IGNORE:
                 return
             if ondouble == ERROR:
-                raise ValueError("Subcommand '{}' is already defined.".format(args[0]))
+                raise ValueError(f"Subcommand '{args[0]}' is already defined.")
             if ondouble == DOUBLE:
                 pass
         else:
@@ -386,7 +386,7 @@ class _SubCommandsDispatch(
         :param ondouble: See :ref:`ondouble`. Default is :data:`IGNORE`.
         """
         return self.add_pattern_executables(
-            r"^{}(?P<command>.*)$".format(prefix), path=path, ondouble=ondouble
+            fr"^{prefix}(?P<command>.*)$", path=path, ondouble=ondouble
         )
 
     def add_function(self, function, command=None, *, help=None, ondouble=ERROR):
